@@ -12,7 +12,7 @@
 #  You should have received a copy of the GNU General Public License along with Firefly. If not, see
 #  <http://www.gnu.org/licenses/>.
 
-from .claim import Claim
+from .role import Role
 from .group import Group
 from .user import User
 
